@@ -70,9 +70,9 @@ def ping():
 
 @main_bp.route('/test')
 def test():
-    bigquery_client = create_bigquery_client()
+    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH, project_id=analytics_conf.BIGQUERY_GCLOUD_PROJECT_ID)
     
-    logger.debug('bigquery_client=%s', bigquery_client)
+    logger.debug('bg_client=%s', bg_client)
     
     return 'Test', 200
 
